from cmath import inf
import copy
import time
import math
from random import Random, shuffle
import copy

#import warnings

from .solution import Solution
#warnings.filterwarnings("ignore")

class Test:

    def __init__(self, mess):
        self.message = mess
        
        
    def print(self):
        print(self.message)

